;; Generated package description from elfeed-web.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "elfeed-web" "4.0.0.0.20260611.1" "Web interface to Elfeed" '((emacs "28.1") (compat "31") (elfeed "4.0.0") (simple-httpd "1.6")) :commit "0bef963f7eaccee21571844730586d8dafa4249f" :authors '(("Christopher Wellons" . "wellons@nullprogram.com")) :maintainer '(("Karthik Chikmagalur" . "karthik.chikmagalur@gmail.com") ("Ihor Radchenko" . "yantar92@posteo.net") ("Daniel Mendler" . "mail@daniel-mendler.de")) :keywords '("network" "hypermedia") :url "https://github.com/emacs-elfeed/elfeed-web")
